(function (exports) {
'use strict';

var Omniture = function (_akamai$amp$Plugin) {
  babelHelpers.inherits(Omniture, _akamai$amp$Plugin);

  /**
   * The Omniture class.
   */
  function Omniture(player, config) {
    babelHelpers.classCallCheck(this, Omniture);

    var _this = babelHelpers.possibleConstructorReturn(this, (Omniture.__proto__ || Object.getPrototypeOf(Omniture)).call(this, player, config));

    _this.adStarted = false;
    return _this;
  }

  babelHelpers.createClass(Omniture, [{
    key: "onready",


    /** */
    value: function onready() {
      this.plugin = window[this.data.main];
      if (this.plugin == null) {
        return;
      }

      try {
        if (this.plugin.Media == null) {
          this.plugin.loadModule("Media");
        } else {
          if (this.plugin.Media.openAd != null && this.player.ads) {
            this.bindHandlers(["onadloaded", "onadstarted", "onadplay", "onadpause", "onadtimeupdate", "onadended"]);
            this.player.ads.addEventListener(akamai.amp.AdEvents.LOADED, this.onadloaded);
            this.player.ads.addEventListener(akamai.amp.AdEvents.STARTED, this.onadstarted);
            this.player.ads.addEventListener(akamai.amp.AdEvents.PLAY, this.onadplay);
            this.player.ads.addEventListener(akamai.amp.AdEvents.PAUSE, this.onadpause);
            this.player.ads.addEventListener(akamai.amp.AdEvents.TIME_UPDATE, this.onadtimeupdate);
            this.player.ads.addEventListener(akamai.amp.AdEvents.ENDED, this.onadended);
          }
        }
      } catch (error) {
        this.error("initialize", error);
      }
    }

    /** */

  }, {
    key: "onmediachange",
    value: function onmediachange() {
      this.started = false;
    }

    /** */

  }, {
    key: "onstarted",
    value: function onstarted() {
      if (this.started === true) {
        return;
      }
      try {
        this.started = true;
        this.plugin.Media.open(this.mediaName, this.player.media.duration, this.playerName);
      } catch (error) {
        this.error(error);
      }
      if (this.player.ads.enabled !== true) {
        this.onplay();
      }
    }

    /** */

  }, {
    key: "onplay",
    value: function onplay() {
      if (this.started !== true) {
        this.onstarted();
        return;
      }
      if (this.adStarted === true) {
        return;
      }
      try {
        this.plugin.Media.play(this.mediaName, this.player.currentTime || 0);
      } catch (error) {
        this.error(error);
      }
    }

    /** */

  }, {
    key: "onpause",
    value: function onpause() {
      if (this.adStarted === true) {
        return;
      }
      try {
        this.plugin.Media.stop(this.mediaName, this.player.currentTime);
      } catch (error) {
        this.error(error);
      }
    }

    /** */

  }, {
    key: "onseeking",
    value: function onseeking() {
      try {
        this.plugin.Media.stop(this.mediaName, this.player.currentTime);
      } catch (error) {
        this.error(error);
      }
    }

    /** */

  }, {
    key: "onseeked",
    value: function onseeked() {
      try {
        this.plugin.Media.play(this.mediaName, this.player.currentTime);
      } catch (error) {
        this.error(error);
      }
    }

    /** */

  }, {
    key: "onended",
    value: function onended() {
      try {
        this.plugin.Media.stop(this.mediaName, this.player.currentTime);
        this.plugin.Media.close(this.mediaName);
        this.started = false;
      } catch (error) {
        this.error(error);
      }
    }

    /** Pluging. */

  }, {
    key: "getAd",
    value: function getAd() {
      return this.ad;
    }
  }, {
    key: "onadloaded",
    value: function onadloaded(event) {
      this.adStarted = false;
      this.adCurrentTime = 0;
      this.ad = event.detail;
    }

    /** */

  }, {
    key: "onadstarted",
    value: function onadstarted() {
      try {
        this.adStarted = true;
        this.plugin.Media.openAd(this.ad.title, this.ad.duration, this.playerName, this.mediaName, this.ad.type, this.ad.position, this.ad.cpm);
        this.adPlay();
      } catch (error) {
        this.error("ad start", error);
      }
    }

    /** */

  }, {
    key: "onadplay",
    value: function onadplay() {
      if (this.adStarted !== true) {
        this.adStart();
      }
      try {
        this.plugin.Media.play(this.ad.title, this.adCurrentTime || 0);
      } catch (error) {
        this.error("ad play", error);
      }
    }

    /** */

  }, {
    key: "onadpause",
    value: function onadpause() {
      try {
        this.plugin.Media.stop(this.ad.title, this.adCurrentTime);
      } catch (error) {
        this.error("ad pause", error);
      }
    }

    /** */

  }, {
    key: "onadtimeupdate",
    value: function onadtimeupdate(value) {
      this.adCurrentTime = value;
    }

    /** */

  }, {
    key: "onadended",
    value: function onadended() {
      if (this.adStarted === false) {
        return;
      }
      try {
        this.adStarted = false;
        this.plugin.Media.stop(this.ad.title, this.ad.duration);
        this.plugin.Media.close(this.ad.title);
      } catch (error) {
        this.error("ad end", error);
      }
      this.play();
    }

    /** */

  }, {
    key: "error",
    value: function error(err) {
      this.logger.error("[AMP Omniture Error]", err);
    }
  }, {
    key: "mediaName",
    get: function get() {
      return this.data.mediaName || this.player.media.title;
    }
  }, {
    key: "playerName",
    get: function get() {
      return this.data.playerName || this.player.config.name || "amp";
    }
  }]);
  return Omniture;
}(akamai.amp.Plugin);

var Heartbeat = function (_Omniture) {
  babelHelpers.inherits(Heartbeat, _Omniture);

  /**
   * The Heartbeat class.
   */
  function Heartbeat(player, config) {
    babelHelpers.classCallCheck(this, Heartbeat);

    var _this = babelHelpers.possibleConstructorReturn(this, (Heartbeat.__proto__ || Object.getPrototypeOf(Heartbeat)).call(this, player, config));

    _this.resumed = false;
    return _this;
  }

  /** */


  babelHelpers.createClass(Heartbeat, [{
    key: "onready",
    value: function onready() {
      var _this2 = this;

      var ahPlugin, appMeasurement, config, delegate, pluginConfig, plugins, visitor;
      babelHelpers.get(Heartbeat.prototype.__proto__ || Object.getPrototypeOf(Heartbeat.prototype), "onready", this).call(this);
      config = this.getConfigurationData();
      if (config.heartbeat.liveLinear != null) {
        this.calculateLiveLinear();
      }
      if (typeof Visitor !== "undefined" && Visitor !== null) {
        visitor = new Visitor(config.visitor.marketingCloudOrgId);
        visitor.trackingServer = config.visitor.trackingServer;
      }
      // Set-up the AppMeasurement component.
      appMeasurement = new AppMeasurement();
      appMeasurement.account = config.account;
      appMeasurement.trackingServer = config.trackingServer;
      appMeasurement.visitor = visitor;
      appMeasurement.pageName = config.pageName;
      appMeasurement.charSet = "UTF-8";
      appMeasurement.visitorID = config.visitorID;
      // Setup the video-player plugin
      delegate = this.createDelegate();
      this.playerPlugin = new ADB.va.plugins.videoplayer.VideoPlayerPlugin(delegate);
      pluginConfig = new ADB.va.plugins.videoplayer.VideoPlayerPluginConfig();
      pluginConfig.debugLogging = this.getDebug();
      this.playerPlugin.configure(pluginConfig);
      // Setup the AppMeasurement plugin.
      delegate = new ADB.va.plugins.aa.AdobeAnalyticsPluginDelegate();
      delegate.onError = function (errorInfo) {
        _this2.facade.logger.error("AdobeAnalyticsPlugin error: " + errorInfo.getMessage() + " | " + errorInfo.getDetails());
      };
      this.aaPlugin = new ADB.va.plugins.aa.AdobeAnalyticsPlugin(appMeasurement, delegate);
      pluginConfig = new ADB.va.plugins.aa.AdobeAnalyticsPluginConfig();
      pluginConfig.channel = config.heartbeat.channel;
      pluginConfig.debugLogging = this.getDebug();
      this.aaPlugin.configure(pluginConfig);
      // Setup the AdobeHeartbeat plugin.
      delegate = new ADB.va.plugins.ah.AdobeHeartbeatPluginDelegate();
      delegate.onError = function (errorInfo) {
        _this2.facade.logger.error("AdobeHeartbeatPlugin error: " + errorInfo.getMessage() + " | " + errorInfo.getDetails());
      };
      ahPlugin = new ADB.va.plugins.ah.AdobeHeartbeatPlugin(delegate);
      pluginConfig = new ADB.va.plugins.ah.AdobeHeartbeatPluginConfig(config.heartbeat.trackingServer, config.heartbeat.publisher);
      pluginConfig.ovp = config.heartbeat.ovp;
      pluginConfig.sdk = config.heartbeat.sdk;
      pluginConfig.ssl = config.heartbeat.ssl === true;
      pluginConfig.debugLogging = this.getDebug();
      ahPlugin.configure(pluginConfig);
      plugins = [this.playerPlugin, this.aaPlugin, ahPlugin];
      // Setup and configure the Heartbeat lib.
      delegate = new ADB.va.HeartbeatDelegate();
      delegate.onError = function (errorInfo) {
        _this2.facade.logger.error("Heartbeat error: " + errorInfo.getMessage() + " | " + errorInfo.getDetails());
      };
      this.heartbeat = new ADB.va.Heartbeat(delegate, plugins);
      pluginConfig = new ADB.va.HeartbeatConfig();
      pluginConfig.debugLogging = this.getDebug();
      this.heartbeat.configure(pluginConfig);
    }

    /** */

  }, {
    key: "calculateLiveLinear",
    value: function calculateLiveLinear() {
      var _this3 = this;

      if (this.liveLinear == null) {
        this.liveLinear = {};
      }
      if (this.liveLinear.updating === true) {
        return;
      }
      this.liveLinear.updating = true;
      var liveLinear = {
        updating: false
      };
      var start = Date.now();
      Utils.getUTC().then(function (utc) {
        var end = Date.now();
        var date = new Date(utc);
        var day = date.toJSON().replace(/([^T]+T).+/, "$1");
        var timezone = _this3.data.heartbeat.liveLinear.timezone || "Z";
        liveLinear.utc = utc;
        date = new Date(start + (end - start) / 2);
        liveLinear.client = date.getTime();
        liveLinear.offset = liveLinear.client - utc;
        date = new Date(day + "00:00:00.000" + timezone);
        liveLinear.start = date.getTime();
        date = new Date(day + "23:59:59.999" + timezone);
        liveLinear.end = date.getTime();
        liveLinear.duration = Math.round((liveLinear.end - liveLinear.start) / 1000);
        _this3.liveLinear = liveLinear;
      });
    }

    /** */

  }, {
    key: "calculateLiveLinearTime",
    value: function calculateLiveLinearTime() {
      var now = Date.now() - this.liveLinear.offset;
      var time = Math.round((now - this.liveLinear.start) / 1000);
      // check for rollover
      if (time > this.liveLinear.duration) {
        time = time - this.liveLinear.duration;
        this.calculateLiveLinear();
      }
      return time;
    }

    /** */

  }, {
    key: "createDelegate",
    value: function createDelegate() {
      var _this4 = this;

      var delegate = new ADB.va.plugins.videoplayer.VideoPlayerPluginDelegate();
      delegate.getVideoInfo = function () {
        var media = _this4.player.media;
        // use the ADB.va.VideoInfo object prototype
        var videoInfo = new ADB.va.plugins.videoplayer.VideoInfo();
        // unique video identifier
        videoInfo.id = media.guid || media.title;
        // video friendly name
        videoInfo.playerName = _this4.playerName;
        videoInfo.name = _this4.mediaName;
        videoInfo.resumed = _this4.resumed;
        var config = _this4.data.heartbeat;
        if (config.liveLinear.enabled === true) {
          videoInfo.length = _this4.liveLinear.duration;
          videoInfo.streamType = ADB.va.plugins.videoplayer.AssetType.ASSET_TYPE_LIVE;
          videoInfo.playhead = _this4.calculateLiveLinearTime();
        } else if (media.getTemporalType() === "live") {
          videoInfo.length = -1;
          videoInfo.streamType = ADB.va.plugins.videoplayer.AssetType.ASSET_TYPE_LIVE;
          videoInfo.playhead = 0;
        } else {
          videoInfo.length = media.duration;
          videoInfo.streamType = ADB.va.plugins.videoplayer.AssetType.ASSET_TYPE_VOD;
          var time = _this4.player.currentTime;
          videoInfo.playhead = time == null || isNaN(time) ? 0 : time;
        }
        return videoInfo;
      };
      delegate.getAdInfo = function () {
        // use the ADB.va.AdInfo object prototype
        var adInfo = new ADB.va.plugins.videoplayer.AdInfo();
        if (_this4.ad == null) {
          return null;
        }
        // The ID of the ad asset
        adInfo.id = _this4.ad.id;
        // The duration (in seconds) of the ad asset
        var duration = _this4.ad.duration;
        adInfo.length = isNaN(duration) || duration === 0 ? -1 : duration;
        //  The position of the pod inside the main content (starting with 1)
        adInfo.position = _this4.ad.position;
        // (optional) The name of the ad asset (opaque string value)
        adInfo.name = _this4.ad.title;
        return adInfo;
      };
      delegate.getAdBreakInfo = function () {
        var adBreakInfo = new ADB.va.plugins.videoplayer.AdBreakInfo();
        if (_this4.ad == null) {
          return null;
        }
        adBreakInfo.name = _this4.ad.type;
        adBreakInfo.position = _this4.ad.position;
        adBreakInfo.playerName = _this4.playerName;
        adBreakInfo.startTime = _this4.player.currentTime;
        return adBreakInfo;
      };
      delegate.getChapterInfo = function () {
        var currentScene = _this4.player.mediaProxy.getScene(_this4.player.currentTime);
        if (currentScene == null) {
          return null;
        }
        // use the ADB.va.ChapterInfo object prototype
        var chapterInfo = new ADB.va.plugins.videoplayer.ChapterInfo();
        // (optional) The name of the chapter (opaque string value)
        chapterInfo.name = currentScene.title;
        // The duration (in seconds) of the chapter
        chapterInfo.length = currentScene.end - currentScene.start;
        // The position of the chapter inside the main content (starting from 1)
        chapterInfo.position = currentScene.position;
        // The offset inside the main content where the chapter starts
        chapterInfo.startTime = currentScene.start;
        return chapterInfo;
      };
      delegate.onError = function (error) {
        _this4.logger.error("Heartbeat Error:", error);
      };
      delegate.getQoSInfo = function () {
        // QoS reports are not available in Adobe Analytics
        var qosInfo = new ADB.va.plugins.videoplayer.QoSInfo();
        // qosInfo.bitrate = 50000
        // qosInfo.fps = 24
        // qosInfo.droppedFrames = 10
        return null;
      };
      return delegate;
    }

    /** */

  }, {
    key: "onmediachange",
    value: function onmediachange() {
      babelHelpers.get(Heartbeat.prototype.__proto__ || Object.getPrototypeOf(Heartbeat.prototype), "onmediachange", this).call(this);
      this.resumed = false;
      var metadata = this.data.heartbeat.metadata;
      if (metadata != null && metadata.video != null) {
        this.aaPlugin.setVideoMetadata(metadata.video);
      }
    }

    /** */

  }, {
    key: "onstarted",
    value: function onstarted() {
      if (this.started === true) {
        return;
      }
      try {
        this.playerPlugin.trackVideoLoad();
        this.started = true;
      } catch (error) {
        this.error(error);
      }
      this.onplay();
    }

    /** */

  }, {
    key: "onplay",
    value: function onplay() {
      if (this.started !== true) {
        this.onstarted();
      }
      try {
        this.playerPlugin.trackPlay();
      } catch (error) {
        this.error(error);
      }
    }

    /** */

  }, {
    key: "onpause",
    value: function onpause() {
      try {
        this.playerPlugin.trackPause();
        this.resumed = true;
      } catch (error) {
        this.error(error);
      }
    }

    /** */

  }, {
    key: "onseeking",
    value: function onseeking() {
      try {
        this.playerPlugin.trackSeekStart();
      } catch (error) {
        this.error(error);
      }
    }

    /** */

  }, {
    key: "onseeked",
    value: function onseeked() {
      try {
        this.playerPlugin.trackSeekComplete();
      } catch (error) {
        this.error(error);
      }
    }

    /** */

  }, {
    key: "onended",
    value: function onended() {
      try {
        this.playerPlugin.trackComplete();
        this.playerPlugin.trackVideoUnload();
        this.started = false;
        this.aaPlugin.setVideoMetadata(null);
      } catch (error) {
        this.error(error);
      }
    }

    /** */

  }, {
    key: "onadstarted",
    value: function onadstarted() {
      var metadata, ref;
      if (this.started !== true) {
        var _metadata = this.data.heartbeat.metadata;
        if (_metadata != null && _metadata.ad != null) {
          this.aaPlugin.setAdMetadata(_metadata.ad);
        }
        this.onstarted();
        setTimeout(this.onadstarted.bind(this), 0);
        return;
      }
      try {
        this.playerPlugin.trackAdStart();
      } catch (error) {
        this.error(error);
      }
    }

    /** */

  }, {
    key: "onadended",
    value: function onadended() {
      try {
        this.playerPlugin.trackAdComplete();
        this.aaPlugin.setAdMetadata(null);
      } catch (error) {
        this.error(error);
      }
    }
  }, {
    key: "onadplay",
    value: function onadplay() {}
  }, {
    key: "onadpause",
    value: function onadpause() {}
  }]);
  return Heartbeat;
}(Omniture);

akamai.amp.AMP.registerPlugin("omniture", function (player, config, key) {
  return akamai.amp.AMP.addResources(config.sdk).then(function () {
    var Class = config.heartbeat != null && config.heartbeat.enabled !== false ? Heartbeat : Omniture;
    akamai.amp.Plugin.createFactory(Class)(player, config, key);
  });
});

exports.Omniture = Omniture;
exports.Heartbeat = Heartbeat;

}((this.akamai.amp.omniture = this.akamai.amp.omniture || {})));
//# sourceMappingURL=Omniture.js.map
